# pisa.utils
Basic utilities underlying much of the work of a data analyzer and one developing for PISA.

These range from statistical functions to file readers/writers and from data smoothing techniques to logging messages.
